==> libquvi-scripts-0.4.5.tar.xz: libquvi-scripts-0.4.5/share/lua/website/publicsenat.lua <==

-- libquvi-scripts v0.4.5
-- Copyright (C) 2010 Raphaël Droz.
--
-- This file is part of libquvi-scripts <http://quvi.googlecode.com/>.
--
-- This library is free software; you can redistribute it and/or
-- modify it under the terms of the GNU Lesser General Public
-- License as published by the Free Software Foundation; either
-- version 2.1 of the License, or (at your option) any later version.
--
-- This library is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public
-- License along with this library; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-- 02110-1301  USA

-- Identify the script.
function ident(self)
    package.path = self.script_dir .. '/?.lua'
    local C      = require 'quvi/const'
    local r      = {}
    r.domain     = "publicsenat%.fr"
    r.formats    = "default"
    r.categories = C.proto_http
    local U      = require 'quvi/util'
    r.handles    = U.handles(self.page_url, {r.domain}, {"/vod/.-%d+"})
    return r
end

-- Query available formats.
function query_formats(self)
    self.formats = 'default'
    return self
end

-- Parse media URL.
function parse(self)
    self.host_id = "publicsenat"

    local p = quvi.fetch (self.page_url)

    self.title = p:match('<title>(.-)%s+%|')
                  or error("no match: media title")

    self.id = self.page_url:match("^http://www.publicsenat.fr/vod/.-(%d+)$")
                or error("no match: media id")

    local c_url = "http://videos.publicsenat.fr/vodiFrame.php?idE="
                    .. self.id

    local c = quvi.fetch(c_url, {fetch_type = 'config'})

    local s = c:match('id="flvEmissionSelect" value="(.-)"')
                or error("no match: media url")

    self.url = {s}

    return self
end

-- vim: set ts=4 sw=4 tw=72 expandtab:

==> libquvi-scripts-0.4.9.tar.xz: libquvi-scripts-0.4.9/share/lua/website/publicsenat.lua <==

-- libquvi-scripts v0.4.9
-- Copyright (C) 2010,2012 Raphaël Droz.
--
-- This file is part of libquvi-scripts <http://quvi.googlecode.com/>.
--
-- This library is free software; you can redistribute it and/or
-- modify it under the terms of the GNU Lesser General Public
-- License as published by the Free Software Foundation; either
-- version 2.1 of the License, or (at your option) any later version.
--
-- This library is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public
-- License along with this library; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-- 02110-1301  USA

-- Identify the script.
function ident(self)
    package.path = self.script_dir .. '/?.lua'
    local C      = require 'quvi/const'
    local r      = {}
    r.domain     = "publicsenat%.fr"
    r.formats    = "default"
    r.categories = C.proto_http
    local U      = require 'quvi/util'
    r.handles    = U.handles(self.page_url, {r.domain}, {"/vod"})
    return r
end

-- Query available formats.
function query_formats(self)
    self.formats = 'default'
    return self
end

-- Parse media URL.
function parse(self)
    self.host_id = "publicsenat"

    local p = quvi.fetch(self.page_url)

    self.title = p:match('<title>(.-)%s+%|') or error("no match: media title")

    self.id = self.page_url:match(".-idE=(%d+)$")
              or self.page_url:match(".-/(%d+)$")
              or error("no match: media ID")

    local t = p:match('id="imgEmissionSelect" value="(.-)"') or ''
    if #t >0 then
      self.thumbnail_url = 'http://publicsenat.fr' .. t
    end

    local u = "http://videos.publicsenat.fr/vodiFrame.php?idE=" ..self.id
    local c = quvi.fetch(u, {fetch_type='config'})

    self.url = {c:match('id="flvEmissionSelect" value="(.-)"')
                or error("no match: media stream URL")}

    return self
end

-- vim: set ts=4 sw=4 tw=72 expandtab:
